<?php

namespace helpers\Markdown;

/**
 * Adds autogenerated ID attributes to titles.
 *
 * E.g. this:
 *
 *     ## Some title
 *
 * Will be modified to this:
 *
 *     ## Some title {#some-title}
 *
 * This syntax to add ID attributes is supported by Markdown Extra.
 */
class TitleIdPreprocessor implements MarkdownParserInterface
{
    /**
     * @var MarkdownParserInterface
     */
    private $wrapped;

    public function __construct(MarkdownParserInterface $wrapped)
    {
        $this->wrapped = $wrapped;
    }

    public function parse($markdown)
    {
        $markdown = preg_replace_callback('/^#+ +([^\{\n]+)$/m', function (array $matches) {
            $title = self::headlineTextToHtmlId($matches[1]);
            return sprintf('%s {#%s}', $matches[0], $title);
        }, $markdown);

        return $this->wrapped->parse($markdown);
    }

    /**
     * @param string $headlineText
     * @return string
     */
    public static function headlineTextToHtmlId($headlineText)
    {
        $headlineText = strip_tags($headlineText);
        $headlineText = trim($headlineText);
        $headlineText = preg_replace('/\s/', '-', $headlineText);
        $headlineText = preg_replace('/[^a-zA-Z0-9\-\_]/', '', $headlineText);
        $headlineText = preg_replace('/(\-)+/', '-', $headlineText);
        $headlineText = strtolower($headlineText);

        return $headlineText;
    }
}
